pub struct ActivityAffects {
pub activity_id: u64,
pub streak_id: u64,
}Fields
activity_id: u64streak_id: u64Trait Implementations
Sourceimpl Bind for ActivityAffects
impl Bind for ActivityAffects
Sourceimpl Debug for ActivityAffects
impl Debug for ActivityAffects
Sourceimpl Entry for ActivityAffects
impl Entry for ActivityAffects
impl Eq for ActivityAffects
Sourceimpl Fetch for ActivityAffects
impl Fetch for ActivityAffects
Sourceimpl HasKey for ActivityAffects
impl HasKey for ActivityAffects
Sourceconst GET_BY_KEY: &'static str
const GET_BY_KEY: &'static str
SELECT (...) WHERE (... = ?) Read moreSourceconst UPSERT: &'static str
const UPSERT: &'static str
INSERT INTO ... VALUES ( ?, ...) ON CONFLICT DO UPDATE SET (x = excluded.x)* Read moreSourceconst KEY_VALUE: NestedValueDef
const KEY_VALUE: NestedValueDef
Definition of the key value (used by
Ref)fn get_key(&self) -> <Self::Key as Tuple<Self::Marker>>::Ref<'_>
fn get_key_mut(&mut self) -> <Self::Key as Tuple<Self::Marker>>::Mut<'_>
fn make_ref(&self) -> Ref<Self>
impl IsValidFor<CacheSchema> for ActivityAffects
impl PartOf<CacheSchema> for ActivityAffects
Sourceimpl PartialEq for ActivityAffects
impl PartialEq for ActivityAffects
Sourcefn eq(&self, other: &ActivityAffects) -> bool
fn eq(&self, other: &ActivityAffects) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ActivityAffects
Sourceimpl Table for ActivityAffects
impl Table for ActivityAffects
Sourceconst NAME: &'static str = "activityaffects"
const NAME: &'static str = "activityaffects"
Name of the table:
#[derive(Table)] uses the lowercase name of the structSourceconst CREATE_TABLE: &'static str
const CREATE_TABLE: &'static str
CREATE TABLE SQL statementSourceconst DEFINITION: TableDef
const DEFINITION: TableDef
The
TableDef struct defines the table and is used to assemble the CREATE_TABLE SQL statementSourceconst ALL_COLUMNS: &'static [&'static str]
const ALL_COLUMNS: &'static [&'static str]
Names of all the
Columns that make up the table.Sourceconst KEY_COLUMNS: &'static [&'static str]
const KEY_COLUMNS: &'static [&'static str]
Sourceconst OTHER_COLUMNS: &'static [&'static str]
const OTHER_COLUMNS: &'static [&'static str]
Names of all the
Columns that make up the table, which aren’t part of the primary key.Sourcetype References = <(<u64 as Value>::References, (<u64 as Value>::References,)) as Filter>::F
type References = <(<u64 as Value>::References, (<u64 as Value>::References,)) as Filter>::F